@@ -235,7 +235,7 @@ vgam <- function(formula,
                                     fit$misc$predictors.names)
     slot(answer, "predictors") = fit$predictors
     if (length(fit$prior.weights))
-        slot(answer, "prior.weights") = fit$prior.weights
+        slot(answer, "prior.weights") = as.matrix(fit$prior.weights)
 
 
     if (nonparametric) {
